@@ -1,25 +1,13 @@
 /*  =========================================================================
     czmq_prelude.h - CZMQ environment
 
-    -------------------------------------------------------------------------
-    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
-    Copyright other contributors as noted in the AUTHORS file.
-
+    Copyright (c) the Contributors as noted in the AUTHORS file.
     This file is part of CZMQ, the high-level C binding for 0MQ:
     http://czmq.zeromq.org.
 
-    This is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by the
-    Free Software Foundation; either version 3 of the License, or (at your
-    option) any later version.
-
-    This software is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABIL-
-    ITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General
-    Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program. If not, see <http://www.gnu.org/licenses/>.
+    This Source Code Form is subject to the terms of the Mozilla Public
+    License, v. 2.0. If a copy of the MPL was not distributed with this
+    file, You can obtain one at http://mozilla.org/MPL/2.0/.
     =========================================================================
 */
 
@@ -155,9 +143,6 @@
 #elif (defined (BSD) || defined (bsd))
 #   define __UTYPE_BSDOS
 #   define __UNIX__
-#elif (defined (APPLE) || defined (__APPLE__))
-#   define __UTYPE_GENERIC
-#   define __UNIX__
 #elif (defined (__ANDROID__))
 #   define __UTYPE_ANDROID
 #   define __UNIX__
@@ -167,6 +152,9 @@
 #   ifndef __NO_CTYPE
 #   define __NO_CTYPE                   //  Suppress warnings on tolower()
 #   endif
+#   ifndef _BSD_SOURCE
+#   define _BSD_SOURCE                  //  Include stuff from 4.3 BSD Unix
+#   endif
 #elif (defined (Mips))
 #   define __UTYPE_MIPS
 #   define __UNIX__
@@ -179,7 +167,7 @@
 #elif (defined (OpenBSD) || defined (__OpenBSD__))
 #   define __UTYPE_OPENBSD
 #   define __UNIX__
-#elif (defined (__APPLE__))
+#elif (defined (APPLE) || defined (__APPLE__))
 #   define __UTYPE_OSX
 #   define __UNIX__
 #elif (defined (NeXT))
@@ -265,6 +253,7 @@
 #   include <grp.h>
 #   include <utime.h>
 #   include <inttypes.h>
+#   include <syslog.h>
 #   include <sys/types.h>
 #   include <sys/param.h>
 #   include <sys/socket.h>
@@ -273,6 +262,7 @@
 #   include <sys/ioctl.h>
 #   include <sys/file.h>
 #   include <sys/wait.h>
+#   include <sys/un.h>
 #   include <sys/uio.h>             //  Let CZMQ build with libzmq/3.x
 #   include <netinet/in.h>          //  Must come before arpa/inet.h
 #   if (!defined (__UTYPE_ANDROID)) && (!defined (__UTYPE_IBMAIX)) \
@@ -351,13 +341,13 @@
 #   endif
 #endif
 
-// Add missing defines for Android.
-#if (defined (__UTYPE_ANDROID))
-#   if (!defined (S_IREAD))
-#      define S_IREAD S_IRUSR
+//  Add missing defines for Android
+#ifdef __UTYPE_ANDROID
+#   ifndef S_IREAD
+#       define S_IREAD S_IRUSR
 #   endif
-#   if (!defined (S_IWRITE))
-#      define S_IWRITE S_IWUSR
+#   ifndef S_IWRITE
+#       define S_IWRITE S_IWUSR
 #   endif
 #endif
 
@@ -406,6 +396,9 @@ typedef struct sockaddr_in inaddr_t;    //  Internet socket address structure
 #endif
 
 //- A number of POSIX and C99 keywords and data types -----------------------
+//  CZMQ uses uint for array indices; equivalent to unsigned int, but more
+//  convenient in code. We define it in czmq_prelude.h on systems that do
+//  not define it by default.
 
 #if (defined (__WINDOWS__))
 #   if (!defined (__cplusplus) && (!defined (inline)))
@@ -422,31 +415,22 @@ typedef struct sockaddr_in inaddr_t;    //  Internet socket address structure
     typedef unsigned int  uint;
 #   if (!defined (__MINGW32__))
     typedef int mode_t;
+    typedef long ssize_t;
     typedef __int32 int32_t;
     typedef __int64 int64_t;
     typedef unsigned __int32 uint32_t;
     typedef unsigned __int64 uint64_t;
-    typedef long ssize_t;
 #   endif
 #   if (!defined (va_copy))
     //  MSVC does not support C99's va_copy so we use a regular assignment
 #       define va_copy(dest,src) (dest) = (src)
 #   endif
-#elif (defined (__APPLE__))
+#elif (defined (__UTYPE_OSX))
     typedef unsigned long ulong;
     typedef unsigned int uint;
 #endif
 
 //- Error reporting ---------------------------------------------------------
-// If the compiler is GCC or supports C99, include enclosing function
-// in CZMQ assertions
-#if defined (__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)
-#   define CZMQ_ASSERT_SANE_FUNCTION    __func__
-#elif defined (__GNUC__) && (__GNUC__ >= 2)
-#   define CZMQ_ASSERT_SANE_FUNCTION    __FUNCTION__
-#else
-#   define CZMQ_ASSERT_SANE_FUNCTION    "<unknown>"
-#endif
 
 //  Replacement for malloc() which asserts if we run out of heap, and
 //  which zeroes the allocated block.
@@ -454,15 +438,14 @@ static inline void *
     safe_malloc (
     size_t size,
     const char *file,
-    unsigned line,
-    const char *func)
+    unsigned line)
 {
     void
         *mem;
 
     mem = calloc (1, size);
     if (mem == NULL) {
-        fprintf (stderr, "FATAL ERROR at %s:%u, in %s\n", file, line, func);
+        fprintf (stderr, "FATAL ERROR at %s:%u\n", file, line);
         fprintf (stderr, "OUT OF MEMORY (malloc returned NULL)\n");
         fflush (stderr);
         abort ();
@@ -478,7 +461,14 @@ static inline void *
 #if defined _ZMALLOC_DEBUG || _ZMALLOC_PEDANTIC
 #   define zmalloc(size) calloc(1,(size))
 #else
-#   define zmalloc(size) safe_malloc((size), __FILE__, __LINE__, CZMQ_ASSERT_SANE_FUNCTION)
+#   define zmalloc(size) safe_malloc((size), __FILE__, __LINE__)
+#endif
+
+//  GCC supports validating format strings for functions that act like printf
+#if defined (__GNUC__) && (__GNUC__ >= 2)
+#   define CHECK_PRINTF(a)   __attribute__((format (printf, a, a + 1)))
+#else
+#   define CHECK_PRINTF(a)
 #endif
 
 //- Socket header files -----------------------------------------------------
@@ -518,6 +508,7 @@ typedef int SOCKET;
 //- Always include ZeroMQ header file ---------------------------------------
 
 #include "zmq.h"
+#include "zmq_utils.h"
 
 #if ZMQ_VERSION_MAJOR == 4
 #   define ZMQ_POLL_MSEC    1           //  zmq_poll is msec
