@@ -1,25 +1,13 @@
 /*  =========================================================================
     zchunk - work with memory chunks
 
-    -------------------------------------------------------------------------
-    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
-    Copyright other contributors as noted in the AUTHORS file.
-
+    Copyright (c) the Contributors as noted in the AUTHORS file.
     This file is part of CZMQ, the high-level C binding for 0MQ:
     http://czmq.zeromq.org.
 
-    This is free software; you can redistribute it and/or modify it under the
-    terms of the GNU Lesser General Public License as published by the Free
-    Software Foundation; either version 3 of the License, or (at your option)
-    any later version.
-
-    This software is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABIL-
-    ITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General
-    Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program. If not, see <http://www.gnu.org/licenses/>.
+    This Source Code Form is subject to the terms of the Mozilla Public
+    License, v. 2.0. If a copy of the MPL was not distributed with this
+    file, You can obtain one at http://mozilla.org/MPL/2.0/.
     =========================================================================
 */
 
@@ -58,7 +46,8 @@ CZMQ_EXPORT size_t
 CZMQ_EXPORT byte *
     zchunk_data (zchunk_t *self);
 
-//  Set chunk data from user-supplied data; truncate if too large
+//  Set chunk data from user-supplied data; truncate if too large. Data may
+//  be null. Returns actual size of chunk
 CZMQ_EXPORT size_t
     zchunk_set (zchunk_t *self, const void *data, size_t size);
 
@@ -70,6 +59,18 @@ CZMQ_EXPORT size_t
 CZMQ_EXPORT size_t
     zchunk_append (zchunk_t *self, const void *data, size_t size);
 
+//  Copy as much data from 'source' into the chunk as possible; returns the
+//  new size of chunk. If all data from 'source' is used, returns exhausted
+//  on the source chunk. Source can be consumed as many times as needed until
+//  it is exhausted. If source was already exhausted, does not change chunk.
+CZMQ_EXPORT size_t
+    zchunk_consume (zchunk_t *self, zchunk_t *source);
+
+//  Returns true if the chunk was exhausted by consume methods, or if the
+//  chunk has a size of zero.
+CZMQ_EXPORT bool
+    zchunk_exhausted (zchunk_t *self);
+
 //  Read chunk from an open file descriptor
 CZMQ_EXPORT zchunk_t *
     zchunk_read (FILE *handle, size_t bytes);
