@@ -1,25 +1,13 @@
 /*  =========================================================================
     zbeacon - LAN discovery and presence
 
-    -------------------------------------------------------------------------
-    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
-    Copyright other contributors as noted in the AUTHORS file.
-
+    Copyright (c) the Contributors as noted in the AUTHORS file.
     This file is part of CZMQ, the high-level C binding for 0MQ:
     http://czmq.zeromq.org.
 
-    This is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by the 
-    Free Software Foundation; either version 3 of the License, or (at your 
-    option) any later version.
-
-    This software is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABIL-
-    ITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General 
-    Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License 
-    along with this program. If not, see <http://www.gnu.org/licenses/>.
+    This Source Code Form is subject to the terms of the Mozilla Public
+    License, v. 2.0. If a copy of the MPL was not distributed with this
+    file, You can obtain one at http://mozilla.org/MPL/2.0/.
     =========================================================================
 */
 
@@ -413,6 +401,9 @@ s_agent_new (void *pipe, int port_nbr)
 #if (defined (__WINDOWS__))
     inaddr_t sockaddr = self->address;
 #else
+#ifndef gai_strerrorA
+    #define gai_strerrorA gai_strerror
+#endif
     inaddr_t sockaddr = self->broadcast;
 #endif
     if (bind (self->udpsock, (struct sockaddr *) &sockaddr, sizeof (sockaddr)) == SOCKET_ERROR)
@@ -425,7 +416,7 @@ s_agent_new (void *pipe, int port_nbr)
     int rc = getnameinfo ((struct sockaddr *) &self->address, sizeof (self->address),
                            hostname, 255, NULL, 0, NI_NUMERICHOST);
     if (rc) {
-        puts (gai_strerror (rc));
+        puts (gai_strerrorA (rc));
         strcpy (hostname, "127.0.0.1");
     }
     zstr_send (pipe, hostname);
@@ -475,11 +466,14 @@ s_get_interface (agent_t *self)
             interface = interface->ifa_next;
         }
         if (strlen (zsys_interface ()) == 0) {
-            //  Subnet broadcast addresses don't work on some platforms but 
-            //  is assumed to work if the interface is specified.
-            self->broadcast.sin_family = AF_INET;
-            self->broadcast.sin_addr.s_addr = INADDR_BROADCAST;
-            self->broadcast.sin_port = htons (self->port_nbr);
+            if (num_interfaces == 0) {
+                //  Subnet broadcast addresses don't work on some platforms 
+                //  but is assumed to work if the interface is specified.
+                self->broadcast.sin_family = AF_INET;
+                self->broadcast.sin_addr.s_addr = INADDR_BROADCAST;
+                self->broadcast.sin_port = htons (self->port_nbr);
+            }
+            else
             if (num_interfaces > 1) {
                 //  Our source address is unknown in this case so set it to
                 //  INADDR_ANY so self->hostname isn't set to an incorrect IP.
