@@ -1,25 +1,13 @@
 /*  =========================================================================
     zchunk - work with memory chunks
 
-    -------------------------------------------------------------------------
-    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
-    Copyright other contributors as noted in the AUTHORS file.
-
+    Copyright (c) the Contributors as noted in the AUTHORS file.
     This file is part of CZMQ, the high-level C binding for 0MQ:
     http://czmq.zeromq.org.
 
-    This is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by the
-    Free Software Foundation; either version 3 of the License, or (at your
-    option) any later version.
-
-    This software is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTA-
-    BILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General
-    Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program. If not, see http://www.gnu.org/licenses/.
+    This Source Code Form is subject to the terms of the Mozilla Public
+    License, v. 2.0. If a copy of the MPL was not distributed with this
+    file, You can obtain one at http://mozilla.org/MPL/2.0/.
     =========================================================================*/
 
 /*
@@ -38,6 +26,7 @@
 struct _zchunk_t {
     size_t size;                //  Current size of data part
     size_t max_size;            //  Maximum allocated size
+    size_t consumed;            //  Amount already consumed
     byte *data;                 //  Data part follows here
 };
 
@@ -56,8 +45,6 @@ zchunk_new (const void *data, size_t size)
             self->size = size;
             memcpy (self->data, data, size);
         }
-        else
-            self->size = 0;
     }
     return self;
 }
@@ -75,7 +62,6 @@ zchunk_destroy (zchunk_t **self_p)
         //  If data was reallocated independently, free it independently
         if (self->data != (byte *) self + sizeof (zchunk_t))
             free (self->data);
-
         free (self);
         *self_p = NULL;
     }
@@ -132,8 +118,8 @@ zchunk_data (zchunk_t *self)
 
 
 //  --------------------------------------------------------------------------
-//  Set chunk data from user-supplied data; truncate if too large
-//  Returns actual size of chunk
+//  Set chunk data from user-supplied data; truncate if too large. Data may
+//  be null. Returns actual size of chunk
 
 size_t
 zchunk_set (zchunk_t *self, const void *data, size_t size)
@@ -141,7 +127,8 @@ zchunk_set (zchunk_t *self, const void *data, size_t size)
     assert (self);
     if (size > self->max_size)
         size = self->max_size;
-    memcpy (self->data, data, size);
+    if (data)
+        memcpy (self->data, data, size);
     self->size = size;
     return size;
 }
@@ -178,6 +165,45 @@ zchunk_append (zchunk_t *self, const void *data, size_t size)
 }
 
 
+//  --------------------------------------------------------------------------
+//  Copy as much data from 'source' into the chunk as possible; returns the
+//  new size of chunk. If all data from 'source' is used, returns exhausted
+//  on the source chunk. Source can be consumed as many times as needed until
+//  it is exhausted. If source was already exhausted, does not change chunk.
+
+size_t
+zchunk_consume (zchunk_t *self, zchunk_t *source)
+{
+    assert (self);
+    assert (source);
+
+    //  We can take at most this many bytes from source
+    size_t size = source->size - source->consumed;
+
+    //  And we can store at most this many bytes in chunk
+    if (self->size + size > self->max_size)
+        size = self->max_size - self->size;
+
+    memcpy (self->data + self->size, source->data + source->consumed, size);
+    source->consumed += size;
+    self->size += size;
+    return self->size;
+}
+
+
+//  --------------------------------------------------------------------------
+//  Returns true if the chunk was exhausted by consume methods, or if the
+//  chunk has a size of zero.
+
+bool
+zchunk_exhausted (zchunk_t *self)
+{
+    assert (self);
+    assert (self->consumed <= self->size);
+    return self->consumed == self->size;
+}
+
+
 //  --------------------------------------------------------------------------
 //  Read chunk from an open file descriptor
 
@@ -291,7 +317,23 @@ zchunk_test (bool verbose)
     assert (memcmp (zchunk_data (copy), "1234567890", 10) == 0);
     assert (zchunk_size (copy) == 10);
     zchunk_destroy (&copy);
-    
+    zchunk_destroy (&chunk);
+
+    copy = zchunk_new ("1234567890abcdefghij", 20);
+    chunk = zchunk_new (NULL, 8);
+    zchunk_consume (chunk, copy);
+    assert (!zchunk_exhausted (copy));
+    assert (memcmp (zchunk_data (chunk), "12345678", 8) == 0);
+    zchunk_set (chunk, NULL, 0);
+    zchunk_consume (chunk, copy);
+    assert (!zchunk_exhausted (copy));
+    assert (memcmp (zchunk_data (chunk), "90abcdef", 8) == 0);
+    zchunk_set (chunk, NULL, 0);
+    zchunk_consume (chunk, copy);
+    assert (zchunk_exhausted (copy));
+    assert (zchunk_size (chunk) == 4);
+    assert (memcmp (zchunk_data (chunk), "ghij", 4) == 0);
+    zchunk_destroy (&copy);
     zchunk_destroy (&chunk);
     //  @end
 
