@@ -1,25 +1,13 @@
 /*  =========================================================================
     zconfig - work with config files written in rfc.zeromq.org/spec:4/ZPL.
 
-    -------------------------------------------------------------------------
-    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
-    Copyright other contributors as noted in the AUTHORS file.
-
+    Copyright (c) the Contributors as noted in the AUTHORS file.
     This file is part of CZMQ, the high-level C binding for 0MQ:
     http://czmq.zeromq.org.
 
-    This is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by the 
-    Free Software Foundation; either version 3 of the License, or (at your 
-    option) any later version.
-
-    This software is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABIL-
-    ITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General 
-    Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License 
-    along with this program. If not, see <http://www.gnu.org/licenses/>.
+    This Source Code Form is subject to the terms of the Mozilla Public
+    License, v. 2.0. If a copy of the MPL was not distributed with this
+    file, You can obtain one at http://mozilla.org/MPL/2.0/.
     =========================================================================
 */
 
@@ -465,8 +453,8 @@ zconfig_chunk_load (zchunk_t *chunk)
         memcpy (cur_line, data_ptr, cur_size);
         cur_line [cur_size] = '\0';
         data_ptr = eoln? eoln + 1: NULL;
-        remaining -= cur_size + 1;
-        
+        remaining -= cur_size + (eoln? 1 :0);
+
         //  Trim line
         int length = strlen (cur_line);
         while (length && isspace ((byte) cur_line [length - 1]))
@@ -814,6 +802,18 @@ zconfig_test (bool verbose)
 
     zconfig_save (root, TESTDIR "/test.cfg");
     zconfig_destroy (&root);
+
+    // Test improperly terminated config files
+    char *chunk_data = "section\n    value = somevalue";
+    zchunk_t *chunk = zchunk_new (chunk_data, strlen (chunk_data));
+    assert (chunk);
+    root = zconfig_chunk_load (chunk);
+    assert(root);
+    char *value = zconfig_resolve (root, "/section/value", NULL);
+    assert (value);
+    assert (streq (value, "somevalue"));
+    zconfig_destroy (&root);
+    zchunk_destroy (&chunk);
     
     //  Delete all test files
     zdir_t *dir = zdir_new (TESTDIR, NULL);
