@@ -1,25 +1,13 @@
 /*  =========================================================================
     zloop - event-driven reactor
 
-    -------------------------------------------------------------------------
-    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
-    Copyright other contributors as noted in the AUTHORS file.
-
+    Copyright (c) the Contributors as noted in the AUTHORS file.
     This file is part of CZMQ, the high-level C binding for 0MQ:
     http://czmq.zeromq.org.
 
-    This is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by the 
-    Free Software Foundation; either version 3 of the License, or (at your 
-    option) any later version.
-
-    This software is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABIL-
-    ITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General 
-    Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License 
-    along with this program. If not, see <http://www.gnu.org/licenses/>.
+    This Source Code Form is subject to the terms of the Mozilla Public
+    License, v. 2.0. If a copy of the MPL was not distributed with this
+    file, You can obtain one at http://mozilla.org/MPL/2.0/.
     =========================================================================
 */
 
@@ -47,8 +35,9 @@ struct _zloop_t {
     size_t poll_size;           //  Size of poll set
     zmq_pollitem_t *pollset;    //  zmq_poll set
     s_poller_t *pollact;        //  Pollers for this poll set
-    bool dirty;                 //  True if pollset needs rebuilding
+    bool need_rebuild;          //  True if pollset needs rebuilding
     bool verbose;               //  True if verbose tracing wanted
+    bool terminated;            //  True when stopped running
     zlist_t *zombies;           //  List of timers to kill
 };
 
@@ -104,6 +93,23 @@ s_timer_new (int timer_id, size_t delay, size_t times, zloop_timer_fn handler, v
     return timer;
 }
 
+//  Remove timer with specified id, if it exists
+
+static void
+s_timer_remove (zloop_t *self, int timer_id)
+{
+    s_timer_t *timer = (s_timer_t *) zlist_first (self->timers);
+    while (timer) {
+        if (timer->timer_id == timer_id) {
+            zlist_remove (self->timers, timer);
+            free (timer);
+            break;
+        }
+        timer = (s_timer_t *) zlist_next (self->timers);
+    }
+}
+
+
 //  We hold an array of pollers that matches the pollset, so we can
 //  register/cancel pollers orthogonally to executing the pollset
 //  activity on pollers. Returns 0 on success, -1 on failure.
@@ -135,7 +141,7 @@ s_rebuild_pollset (zloop_t *self)
         item_nbr++;
         poller = (s_poller_t *) zlist_next (self->pollers);
     }
-    self->dirty = false;
+    self->need_rebuild = false;
     return 0;
 }
 
@@ -157,7 +163,7 @@ s_tickless_timer (zloop_t *self)
     if (timeout < 0)
         timeout = 0;
     if (self->verbose)
-        zclock_log ("I: zloop: polling for %d msec", timeout);
+	zclock_log ("I: zloop: polling for %d msec", (int)timeout);
     return timeout;
 }
 
@@ -236,16 +242,16 @@ zloop_poller (zloop_t *self, zmq_pollitem_t *item, zloop_fn handler, void *arg)
 {
     assert (self);
 
-    if (item->socket)
-        if (streq (zsocket_type_str (item->socket), "UNKNOWN"))
-            return -1;
+    if (item->socket
+    &&  streq (zsocket_type_str (item->socket), "UNKNOWN"))
+        return -1;
 
     s_poller_t *poller = s_poller_new (item, handler, arg);
     if (poller) {
         if (zlist_append (self->pollers, poller))
             return -1;
 
-        self->dirty = true;
+        self->need_rebuild = true;
         if (self->verbose)
             zclock_log ("I: zloop: register %s poller (%p, %d)",
                 item->socket? zsocket_type_str (item->socket): "FD",
@@ -274,7 +280,8 @@ zloop_poller_end (zloop_t *self, zmq_pollitem_t *item)
         ||  (item->fd     && item->fd     == poller->item.fd)) {
             zlist_remove (self->pollers, poller);
             free (poller);
-            self->dirty = true;
+            //  Force rebuild to avoid reading from freed poller
+            self->need_rebuild = true;
         }
         poller = (s_poller_t *) zlist_next (self->pollers);
     }
@@ -309,9 +316,9 @@ zloop_set_tolerant (zloop_t *self, zmq_pollitem_t *item)
 
 //  --------------------------------------------------------------------------
 //  Register a timer that expires after some delay and repeats some number of
-//  times. At each expiry, will call the handler, passing the arg. To
-//  run a timer forever, use 0 times. Returns a non-negative timer id if OK, 
-//  or -1 if there was an error.
+//  times. At each expiry, will call the handler, passing the arg. To run a
+//  timer forever, use 0 times. Returns a timer_id that is used to cancel the
+//  timer in the future. Returns -1 if there was an error.
 
 int
 zloop_timer (zloop_t *self, size_t delay, size_t times, zloop_timer_fn handler, void *arg)
@@ -324,7 +331,7 @@ zloop_timer (zloop_t *self, size_t delay, size_t times, zloop_timer_fn handler,
     if (zlist_append (self->timers, timer))
         return -1;
     if (self->verbose)
-        zclock_log ("I: zloop: register timer id=%d delay=%d times=%d", 
+        zclock_log ("I: zloop: register timer id=%d delay=%zd times=%zd", 
                     timer_id, delay, times);
     
     return timer_id;
@@ -340,10 +347,12 @@ zloop_timer_end (zloop_t *self, int timer_id)
 {
     assert (self);
     
+    if (self->terminated)
+        s_timer_remove (self, timer_id);
+    else
     //  We cannot touch self->timers because we may be executing that
     //  from inside the poll loop. So, we hold the arg on the zombie
     //  list, and process that list when we're done executing timers.
-
     //  This hack lets us store an integer timer ID as a pointer
     if (zlist_append (self->zombies, (byte *) NULL + timer_id))
         return -1;
@@ -387,9 +396,9 @@ zloop_start (zloop_t *self)
     }
     //  Main reactor loop
     while (!zctx_interrupted) {
-        if (self->dirty) {
-            // If s_rebuild_pollset() fails, break out of the loop and
-            // return its error
+        if (self->need_rebuild) {
+            //  If s_rebuild_pollset() fails, break out of the loop and
+            //  return its error
             rc = s_rebuild_pollset (self);
             if (rc)
                 break;
@@ -452,37 +461,22 @@ zloop_start (zloop_t *self)
                             zsocket_type_str (poller->item.socket): "FD",
                         poller->item.socket, poller->item.fd);
                 rc = poller->handler (self, &self->pollset [item_nbr], poller->arg);
-                if (rc == -1)
-                    break;      //  Poller handler signaled break
-                    
-                //  If the poller handler calls zloop_poller_end on a poller 
-                //  other than itself, we need to force rebuild in order to 
-                //  avoid reading from freed memory in the handler.
-                if (self->dirty) {
-                    if (self->verbose)
-                        zclock_log ("I: zloop: pollers canceled, forcing rebuild");
-                    break;
-                }
+                if (rc == -1 || self->need_rebuild)
+                    break; 
             }
         }
         //  Now handle any timer zombies
         //  This is going to be slow if we have many timers; we might use
         //  a faster lookup on the timer list.
         while (zlist_size (self->zombies)) {
-            //  This hack lets us convert our pointer back into an integer timer_id
+            //  Get timer_id back from pointer
             int timer_id = (byte *) zlist_pop (self->zombies) - (byte *) NULL;
-            timer = (s_timer_t *) zlist_first (self->timers);
-            while (timer) {
-                if (timer->timer_id == timer_id) {
-                    zlist_remove (self->timers, timer);
-                    free (timer);
-                }
-                timer = (s_timer_t *) zlist_next (self->timers);
-            }
+            s_timer_remove (self, timer_id);
         }
         if (rc == -1)
             break;
     }
+    self->terminated = true;
     return rc;
 }
 
