@@ -2,7 +2,7 @@
     zmsg - working with multipart messages
 
     -------------------------------------------------------------------------
-    Copyright (c) 1991-2013 iMatix Corporation <www.imatix.com>
+    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
     Copyright other contributors as noted in the AUTHORS file.
 
     This file is part of CZMQ, the high-level C binding for 0MQ:
@@ -87,7 +87,7 @@ zmsg_destroy (zmsg_t **self_p)
 //  --------------------------------------------------------------------------
 //  Receive message from socket, returns zmsg_t object or NULL if the recv
 //  was interrupted. Does a blocking recv, if you want to not block then use
-//  the zloop class or zmq_poll to check for socket input before receiving.
+//  the zloop class or zmsg_recv_nowait() or zmq_poll to check for socket input before receiving.
 
 zmsg_t *
 zmsg_recv (void *zocket)
@@ -113,6 +113,35 @@ zmsg_recv (void *zocket)
     return self;
 }
 
+//  --------------------------------------------------------------------------
+//  Receive message from socket, returns zmsg_t object, or NULL either if there was
+//  no input waiting, or the recv was interrupted.
+
+zmsg_t *
+zmsg_recv_nowait (void *zocket)
+{
+    assert (zocket);
+    int frames = 0;
+    zmsg_t *self = zmsg_new ();
+    if (!self)
+        return NULL;
+    
+    while (true) {
+        zframe_t *frame = zframe_recv_nowait (zocket);
+        if (!frame) {
+            zmsg_destroy (&self);
+            break;              //  Interrupted or terminated
+        }
+        if (zmsg_append (self, &frame)) {
+            zmsg_destroy (&self);
+            break;
+        }
+        if (!zsocket_rcvmore (zocket))
+            break;              //  Last message frame
+        frames++;
+    }
+    return frames > 0 ? self : NULL;
+}
 
 //  --------------------------------------------------------------------------
 //  Send message to socket, destroy after sending. If the message has no
@@ -170,30 +199,18 @@ zmsg_content_size (zmsg_t *self)
 //  --------------------------------------------------------------------------
 //  Push frame to the front of the message, i.e. before all other frames.
 //  Message takes ownership of frame, will destroy it when message is sent.
-//  Returns 0 on success, -1 on error.
+//  Returns 0 on success, -1 on error. Deprecates zmsg_push, which did not
+//  nullify the caller's frame reference.
 
 int
-zmsg_push (zmsg_t *self, zframe_t *frame)
+zmsg_prepend (zmsg_t *self, zframe_t **frame_p)
 {
     assert (self);
-    assert (frame);
+    assert (frame_p);
+    zframe_t *frame = *frame_p;
+    *frame_p = NULL;            //  We now own frame
     self->content_size += zframe_size (frame);
-    return zlist_push (self->frames, (void *) frame);
-}
-
-
-//  --------------------------------------------------------------------------
-//  Remove first frame from message, if any. Returns frame, or NULL. Caller
-//  now owns frame and must destroy it when finished with it.
-
-zframe_t *
-zmsg_pop (zmsg_t *self)
-{
-    assert (self);
-    zframe_t *frame = (zframe_t *) zlist_pop (self->frames);
-    if (frame)
-        self->content_size -= zframe_size (frame);
-    return frame;
+    return zlist_push (self->frames, frame);
 }
 
 
@@ -215,17 +232,17 @@ zmsg_append (zmsg_t *self, zframe_t **frame_p)
 
 
 //  --------------------------------------------------------------------------
-//  Add frame to the end of the message, i.e. after all other frames.
-//  Message takes ownership of frame, will destroy it when message is sent.
-//  Returns 0 on success. Deprecated by zmsg_append ().
+//  Remove first frame from message, if any. Returns frame, or NULL. Caller
+//  now owns frame and must destroy it when finished with it.
 
-int
-zmsg_add (zmsg_t *self, zframe_t *frame)
+zframe_t *
+zmsg_pop (zmsg_t *self)
 {
     assert (self);
-    assert (frame);
-    self->content_size += zframe_size (frame);
-    return zlist_append (self->frames, frame);
+    zframe_t *frame = (zframe_t *) zlist_pop (self->frames);
+    if (frame)
+        self->content_size -= zframe_size (frame);
+    return frame;
 }
 
 
@@ -265,11 +282,41 @@ zmsg_addmem (zmsg_t *self, const void *src, size_t size)
 
 
 //  --------------------------------------------------------------------------
-//  Push string as new frame to front of message, returns 0 if OK, -1 on
-//  error. The string is formatted using sprintf. 
+//  Push string as new frame to front of message.
+//  Returns 0 on success, -1 on error.
 
 int
-zmsg_pushstr (zmsg_t *self, const char *format, ...)
+zmsg_pushstr (zmsg_t *self, const char *string)
+{
+    assert (self);
+    assert (string);
+    self->content_size += strlen (string);
+    zlist_push (self->frames, zframe_new (string, strlen (string)));
+    return 0;
+}
+
+
+//  --------------------------------------------------------------------------
+//  Push string as new frame to end of message.
+//  Returns 0 on success, -1 on error.
+
+int
+zmsg_addstr (zmsg_t *self, const char *string)
+{
+    assert (self);
+    assert (string);
+    self->content_size += strlen (string);
+    zlist_append (self->frames, zframe_new (string, strlen (string)));
+    return 0;
+}
+
+
+//  --------------------------------------------------------------------------
+//  Push formatted string as new frame to front of message.
+//  Returns 0 on success, -1 on error.
+
+int
+zmsg_pushstrf (zmsg_t *self, const char *format, ...)
 {
     assert (self);
     assert (format);
@@ -278,7 +325,7 @@ zmsg_pushstr (zmsg_t *self, const char *format, ...)
     va_start (argptr, format);
     char *string = zsys_vprintf (format, argptr);
     va_end (argptr);
-    
+
     self->content_size += strlen (string);
     zlist_push (self->frames, zframe_new (string, strlen (string)));
     free (string);
@@ -287,10 +334,11 @@ zmsg_pushstr (zmsg_t *self, const char *format, ...)
 
 
 //  --------------------------------------------------------------------------
-//  Push string as new frame to end of message
+//  Push formatted string as new frame to end of message.
+//  Returns 0 on success, -1 on error.
 
 int
-zmsg_addstr (zmsg_t *self, const char *format, ...)
+zmsg_addstrf (zmsg_t *self, const char *format, ...)
 {
     assert (self);
     assert (format);
@@ -299,13 +347,14 @@ zmsg_addstr (zmsg_t *self, const char *format, ...)
     va_start (argptr, format);
     char *string = zsys_vprintf (format, argptr);
     va_end (argptr);
-    
+
     self->content_size += strlen (string);
     zlist_append (self->frames, zframe_new (string, strlen (string)));
     free (string);
     return 0;
 }
 
+
 //  --------------------------------------------------------------------------
 //  Pop frame off front of message, return as fresh string. If there were
 //  no more frames in the message, returns NULL.
@@ -325,20 +374,6 @@ zmsg_popstr (zmsg_t *self)
 }
 
 
-//  --------------------------------------------------------------------------
-//  Push frame plus empty frame to front of message, before first frame.
-//  Message takes ownership of frame, will destroy it when message is sent.
-
-void
-zmsg_wrap (zmsg_t *self, zframe_t *frame)
-{
-    assert (self);
-    assert (frame);
-    if (zmsg_pushmem (self, "", 0) == 0)
-        zmsg_push (self, frame);
-}
-
-
 //  --------------------------------------------------------------------------
 //  Pop frame off front of message, caller now owns frame
 //  If next frame is empty, pops and destroys that empty frame.
@@ -578,14 +613,11 @@ zmsg_t *
 zmsg_dup (zmsg_t *self)
 {
     assert (self);
-    zframe_t *frame = zmsg_first (self);
-    if (!frame)
-        return NULL;
-
     zmsg_t *copy = zmsg_new ();
     if (!copy)
         return NULL;
 
+    zframe_t *frame = zmsg_first (self);
     while (frame) {
         if (zmsg_addmem (copy, zframe_data (frame), zframe_size (frame))) {
             zmsg_destroy (&copy);
@@ -598,23 +630,11 @@ zmsg_dup (zmsg_t *self)
 
 
 //  --------------------------------------------------------------------------
-//  Dump message to stderr, for debugging and tracing.
-//  See zmsg_dump_to_stream() for details
+//  Dump message to FILE stream, for debugging and tracing.
+//  Truncates to first 10 frames, for readability.
 
 void
-zmsg_dump (zmsg_t *self)
-{
-   zmsg_dump_to_stream (self, stderr);
-}
-
-
-//  --------------------------------------------------------------------------
-//  Dump message to FILE stream, for debugging and tracing. 
-//  Truncates to first 10 frames, for readability; this may be unfortunate
-//  when debugging larger and more complex messages.
-
-void
-zmsg_dump_to_stream (zmsg_t *self, FILE *file)
+zmsg_fprint (zmsg_t *self, FILE *file)
 {
     fprintf (file, "--------------------------------------\n");
     if (!self) {
@@ -624,12 +644,70 @@ zmsg_dump_to_stream (zmsg_t *self, FILE *file)
     zframe_t *frame = zmsg_first (self);
     int frame_nbr = 0;
     while (frame && frame_nbr++ < 10) {
-        zframe_print_to_stream(frame, NULL, file);
+        zframe_fprint (frame, NULL, file);
         frame = zmsg_next (self);
     }
 }
 
 
+//  --------------------------------------------------------------------------
+//  Dump message to stderr, for debugging and tracing.
+//  See zmsg_fprint for details
+
+void
+zmsg_print (zmsg_t *self)
+{
+   zmsg_fprint (self, stderr);
+}
+
+
+//  --------------------------------------------------------------------------
+//  Push frame plus empty frame to front of message, before first frame.
+//  Message takes ownership of frame, will destroy it when message is sent.
+//  DEPRECATED as unsafe -- does not nullify frame reference.
+
+void
+zmsg_wrap (zmsg_t *self, zframe_t *frame)
+{
+    assert (self);
+    assert (frame);
+    if (zmsg_pushmem (self, "", 0) == 0)
+        zmsg_push (self, frame);
+}
+
+
+//  --------------------------------------------------------------------------
+//  Push frame to the front of the message, i.e. before all other frames.
+//  Message takes ownership of frame, will destroy it when message is sent.
+//  Returns 0 on success, -1 on error.
+//  DEPRECATED by zmsg_prepend ().
+
+int
+zmsg_push (zmsg_t *self, zframe_t *frame)
+{
+    assert (self);
+    assert (frame);
+    self->content_size += zframe_size (frame);
+    return zlist_push (self->frames, frame);
+}
+
+
+//  --------------------------------------------------------------------------
+//  Add frame to the end of the message, i.e. after all other frames.
+//  Message takes ownership of frame, will destroy it when message is sent.
+//  Returns 0 on success.
+//  DEPRECATED by zmsg_append ().
+
+int
+zmsg_add (zmsg_t *self, zframe_t *frame)
+{
+    assert (self);
+    assert (frame);
+    self->content_size += zframe_size (frame);
+    return zlist_append (self->frames, frame);
+}
+
+
 //  --------------------------------------------------------------------------
 //  Selftest
 
@@ -655,7 +733,7 @@ zmsg_test (bool verbose)
     assert (msg);
     zframe_t *frame = zframe_new ("Hello", 5);
     assert (frame);
-    zmsg_push (msg, frame);
+    zmsg_prepend (msg, &frame);
     assert (zmsg_size (msg) == 1);
     assert (zmsg_content_size (msg) == 5);
     rc = zmsg_send (&msg, output);
@@ -756,12 +834,12 @@ zmsg_test (bool verbose)
     assert (zmsg_content_size (msg) == 12);
     frame = zframe_new ("Address", 7);
     assert (frame);
-    zmsg_wrap (msg, frame);
-    assert (zmsg_size (msg) == 4);
+    zmsg_prepend (msg, &frame);
+    assert (zmsg_size (msg) == 3);
     rc = zmsg_addstr (msg, "Body");
     assert (rc == 0);
-    assert (zmsg_size (msg) == 5);
-    frame = zmsg_unwrap (msg);
+    assert (zmsg_size (msg) == 4);
+    frame = zmsg_pop (msg);
     zframe_destroy (&frame);
     assert (zmsg_size (msg) == 3);
     char *body = zmsg_popstr (msg);
