@@ -1,25 +1,13 @@
 /*  =========================================================================
     zpoller - trivial socket poller class
 
-    -------------------------------------------------------------------------
-    Copyright (c) 1991-2014 iMatix Corporation <www.imatix.com>
-    Copyright other contributors as noted in the AUTHORS file.
-
+    Copyright (c) the Contributors as noted in the AUTHORS file.
     This file is part of CZMQ, the high-level C binding for 0MQ:
     http://czmq.zeromq.org.
 
-    This is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by the
-    Free Software Foundation; either version 3 of the License, or (at your
-    option) any later version.
-
-    This software is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTA-
-    BILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General
-    Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program. If not, see http://www.gnu.org/licenses/.
+    This Source Code Form is subject to the terms of the Mozilla Public
+    License, v. 2.0. If a copy of the MPL was not distributed with this
+    file, You can obtain one at http://mozilla.org/MPL/2.0/.
     =========================================================================*/
 
 /*
@@ -40,7 +28,7 @@ struct _zpoller_t {
     zlist_t *readers;           //  List of sockets to read from
     zmq_pollitem_t *poll_set;   //  Current zmq_poll set
     size_t poll_size;           //  Size of poll set
-    bool dirty;                 //  Does pollset needs rebuilding?
+    bool need_rebuild;          //  Does pollset needs rebuilding?
     bool expired;               //  Did poll timer expire?
     bool terminated;            //  Did poll call end with EINTR?
 };
@@ -58,7 +46,7 @@ zpoller_new (void *reader, ...)
     zpoller_t *self = (zpoller_t *) zmalloc (sizeof (zpoller_t));
     assert (self);
     self->readers = zlist_new ();
-    self->dirty = true;
+    self->need_rebuild = true;
 
     va_list args;
     va_start (args, reader);
@@ -89,7 +77,7 @@ zpoller_destroy (zpoller_t **self_p)
 
 
 //  --------------------------------------------------------------------------
-//  Add a reader to be polled.
+//  Add a reader to be polled
 
 int
 zpoller_add (zpoller_t *self, void *reader)
@@ -98,7 +86,7 @@ zpoller_add (zpoller_t *self, void *reader)
     assert (reader);
     int rc = zlist_append (self->readers, reader);
     if (rc != -1)
-        self->dirty = true;
+        self->need_rebuild = true;
     return rc;
 }
 
@@ -117,7 +105,7 @@ zpoller_wait (zpoller_t *self, int timeout)
 {
     self->expired = false;
     self->terminated = false;
-    if (self->dirty)
+    if (self->need_rebuild)
         s_rebuild_poll_set (self);
         
     int rc = zmq_poll (self->poll_set, (int) self->poll_size,
@@ -159,7 +147,7 @@ s_rebuild_poll_set (zpoller_t *self)
         reader_nbr++;
         reader = zlist_next (self->readers);
     }
-    self->dirty = false;
+    self->need_rebuild = false;
     return 0;
 }
 
